summaryrefslogtreecommitdiffstats
path: root/kmail/kmaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmaccount.h')
-rw-r--r--kmail/kmaccount.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmaccount.h b/kmail/kmaccount.h
index 44cd67b0..2872b111 100644
--- a/kmail/kmaccount.h
+++ b/kmail/kmaccount.h
@@ -206,9 +206,9 @@ public:
virtual void setHasInbox( bool has ) { mHasInbox = has; }
/**
* If this account is a disconnected IMAP account, invalidate it.
*/
- virtual void invalidateIMAPFolders();
+ virtual void tqinvalidateIMAPFolders();
/**
* Determines whether the account can be checked, currently.
@@ -206,9 +206,9 @@ public:
virtual void setHasInbox( bool has ) { mHasInbox = has; }
/**
- * If this account is a disconnected IMAP account, invalidate it.
+ * If this account is a disconnected IMAP account, tqinvalidate it.
*/